References
==========

This page contains a full list of references cited in the documentation, including the original work of :ref:`references:Berry, Levinsohn, and Pakes (1995)`. If you use PyBLP in your research, we ask that you also cite the below :ref:`references:Conlon and Gortmaker (2020)`, which describes the advances implemented in the package.


Conlon and Gortmaker (2020)
---------------------------

Conlon, Christopher T., and Jeff Gortmaker (2020). `Best practices for differentiated products demand estimation with PyBLP <https://jeffgortmaker.com/files/pyblp.pdf>`_. Working paper.


Other References
----------------

Amemiya (1977)
~~~~~~~~~~~~~~

Amemiya, Takeshi (1977). `A note on a heteroscedastic model <https://ideas.repec.org/a/eee/econom/v6y1977i3p365-370.html>`_. *Journal of Econometrics, 6* (3), 365-370.


Andrews, Gentzkow, and Shapiro (2017)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Andrews, Isaiah, Matthew Gentzkow, and Jesse M. Shapiro (2017). `Measuring the sensitivity of parameter estimates to estimation moments <https://ideas.repec.org/a/oup/qjecon/v132y2017i4p1553-1592..html>`_. *Quarterly Journal of Economics, 132* (4), 1553-1592.


Armstrong (2016)
~~~~~~~~~~~~~~~~

Armstrong, Timothy B. (2016). `Large market asymptotics for differentiated product demand estimators with economic models of supply <https://ideas.repec.org/a/wly/emetrp/v84y2016ip1961-1980.html>`_. *Econometrica, 84* (5), 1961-1980.


Berry (1994)
~~~~~~~~~~~~

Berry, Steven (1994). `Estimating discrete-choice models of product  differentiation <https://ideas.repec.org/a/rje/randje/v25y1994isummerp242-262.html>`_. *RAND Journal of Economics, 25* (2), 242-262.


Berry, Levinsohn, and Pakes (1995)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Berry, Steven, James Levinsohn, and Ariel Pakes (1995). `Automobile prices in market equilibrium <https://ideas.repec.org/a/ecm/emetrp/v63y1995i4p841-90.html>`_. *Econometrica, 63* (4), 841-890.


Berry, Levinsohn, and Pakes (1999)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Berry, Steven, James Levinsohn, and Ariel Pakes (1999). `Voluntary export restraints on automobiles: Evaluating a trade policy <https://ideas.repec.org/a/aea/aecrev/v89y1999i3p400-430.html>`_. *American Economic Review, 83* (9), 400-430.


Berry, Levinsohn, and Pakes (2004)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Berry, Steven, James Levinsohn, and Ariel Pakes (2004). `Differentiated products demand systems from a combination of micro and macro data: The new car market <https://ideas.repec.org/a/ucp/jpolec/v112y2004i1p68-105.html>`_. *Journal of Political Economy, 112* (1), 68-105.


Berry and Pakes (2007)
~~~~~~~~~~~~~~~~~~~~~~

Berry, Steven, and Ariel Pakes (2007). `The pure characteristics demand model <https://ideas.repec.org/a/ier/iecrev/v48y2007i4p1193-1225.html>`_. *International Economic Review, 48* (4), 1193-1225.


Brenkers and Verboven (2006)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Brenkers, Randy, and Frank Verboven (2006). `Liberalizing a distribution system: The European car market <https://ideas.repec.org/a/tpr/jeurec/v4y2006i1p216-251.html>`_. *Journal of the European Economic Association, 4* (1), 216-251.


Brunner, Heiss, Romahn, and Weiser (2017)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Brunner, Daniel, Florian Heiss, André Romahn, and Constantin Weiser (2017) `Reliable estimation of random coefficient logit demand models <https://ideas.repec.org/p/zbw/dicedp/267.html>`_. DICE Discussion Paper 267.


Cardell (1997)
~~~~~~~~~~~~~~

Cardell, N. Scott (1997). `Variance components structures for the extreme-value and logistic distributions with application to models of heterogeneity <https://ideas.repec.org/a/cup/etheor/v13y1997i02p185-213_00.html>`_. *Econometric Theory, 13* (2), 185-213.


Chamberlain (1987)
~~~~~~~~~~~~~~~~~~

Chamberlain, Gary (1987) `Asymptotic efficiency in estimation with conditional moment restrictions <https://ideas.repec.org/a/eee/econom/v34y1987i3p305-334.html>`_. *Journal of Econometrics, 34* (3), 305-334.


Conlon and Mortimer (2018)
~~~~~~~~~~~~~~~~~~~~~~~~~~

Conlon, Christopher T., and Julie H. Mortimer (2018). `Empirical properties of diversion ratios <https://ideas.repec.org/p/nbr/nberwo/24816.html>`_. NBER working paper 24816.


Frisch and Waugh (1933)
~~~~~~~~~~~~~~~~~~~~~~~

Frisch, Ragnar, and Frederick V. Waugh (1933). `Partial time regressions as compared with individual trends <https://www.econometricsociety.org/publications/econometrica/1933/10/01/partial-time-regressions-compared-individual-trends>`_. *Econometrica, 1* (4), 387-401.


Gandhi and Houde (2017)
~~~~~~~~~~~~~~~~~~~~~~~

Gandhi, Amit, and Jean-François Houde (2017). `Measuring substitution patterns in differentiated products industries <https://jfhoude.wiscweb.wisc.edu/wp-content/uploads/sites/769/2018/08/GH_v6.pdf>`_. Working paper.


Grigolon and Verboven (2014)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Grigolon, Laura, and Frank Verboven (2014). `Nested logit or random coefficients logit? A comparison of alternative discrete choice models of product differentiation <https://ideas.repec.org/a/tpr/restat/v96y2014i5p916-935.html>`_. *Review of Economics and Statistics, 96* (5), 916-935.


Hansen (1982)
~~~~~~~~~~~~~

Hansen, Lars Peter (1982). `Large sample properties of generalized method of moments estimators <https://ideas.repec.org/a/ecm/emetrp/v50y1982i4p1029-54.html>`_. *Econometrica, 50* (4), 1029-1054.


Heiss and Winschel (2008)
~~~~~~~~~~~~~~~~~~~~~~~~~

Heiss, Florian, and Viktor Winschel (2008). `Likelihood approximation by numerical integration on sparse grids <https://ideas.repec.org/a/eee/econom/v144y2008i1p62-80.html>`_. *Journal of Econometrics, 144* (1), 62-80.


Hess, Train, and Polak (2004)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Hess, Stephane, Kenneth E. Train, and John W. Polak (2004). `On the use of a Modified Latin Hypercube Sampling (MLHS) method in the estimation of a mixed logit model for vehicle choice <https://ideas.repec.org/a/eee/transb/v40y2006i2p147-163.html>`_. *Transportation Research Part B* (40), 147-167.


Imbens and Lancaster (1994)
~~~~~~~~~~~~~~~~~~~~~~~~~~~

Imbens, Guido W., and Tony Lancaster (1994). `Combining micro and macro data in microeconometric models <https://ideas.repec.org/a/oup/restud/v61y1994i4p655-680..html>`_. *Review of Economic Studies, 61* (4), 655-680.


Judd and Skrainka (2011)
~~~~~~~~~~~~~~~~~~~~~~~~

Judd, Kenneth L., and Ben Skrainka (2011). `High performance quadrature rules: How numerical integration affects a popular model of product differentiation <https://ideas.repec.org/p/ifs/cemmap/03-11.html>`_. CeMMAP working paper CWP03/11.


Knittel and Metaxoglou (2014)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Knittel, Christopher R., and Konstantinos Metaxoglou (2014). `Estimation of random-coefficient demand models: Two empiricists' perspective <https://ideas.repec.org/a/tpr/restat/v96y2014i1p34-59.html>`_. *Review of Economics and Statistics, 96* (1), 34-59.


Lovell (1963)
~~~~~~~~~~~~~

Lovell, Michael C. (1963). `Seasonal adjustment of economic time series and multiple regression analysis <https://www.tandfonline.com/doi/abs/10.1080/01621459.1963.10480682>`_. *Journal of the American Statistical Association, 58* (304), 993-1010.


Morrow and Skerlos (2011)
~~~~~~~~~~~~~~~~~~~~~~~~~

Morrow, W. Ross, and Steven J. Skerlos (2011). `Fixed-point approaches to computing Bertrand-Nash equilibrium prices under mixed-logit demand <https://ideas.repec.org/a/inm/oropre/v59y2011i2p328-345.html>`_. *Operations Research, 59* (2), 328-345.


Nevo (1997)
~~~~~~~~~~~

Nevo, Aviv (1997). `Mergers with differentiated products: The case of the ready-to-eat cereal industry <https://ideas.repec.org/p/cdl/compol/qt1d53t6ts.html>`_. Competition Policy Center, Working Paper Series qt1d53t6ts, Competition Policy Center, Institute for Business and Economic Research, UC Berkeley.


Nevo (2000)
~~~~~~~~~~~

Nevo, Aviv (2000). `A practitioner's guide to estimation of random‐coefficients logit models of demand <https://ideas.repec.org/a/bla/jemstr/v9y2000i4p513-548.html>`_. *Journal of Economics & Management Strategy, 9* (4), 513-548.


Newey and West (1987)
~~~~~~~~~~~~~~~~~~~~~

Newey, Whitney K., and Kenneth D. West (1987). `Hypothesis testing with efficient method of moments estimation <https://ideas.repec.org/a/ier/iecrev/v28y1987i3p777-87.html>`_. *International Economic Review, 28* (3), 777-787.


Owen (2013)
~~~~~~~~~~~

Owen, Art B. (2013). `Monte Carlo theory, methods and examples <https://statweb.stanford.edu/~owen/mc/>`_.


Owen (2017)
~~~~~~~~~~~

Owen, Art B. (2017). `A randomized Halton algorithm in R <https://arxiv.org/pdf/1706.02808.pdf>`_.


Petrin (2002)
~~~~~~~~~~~~~

Petrin, Amil (2002). `Quantifying the benefits of new products: The case of the minivan <https://ideas.repec.org/a/ucp/jpolec/v110y2002i4p705-729.html>`_. *Journal of Political Economy, 110* (4), 705-729.


Reynaert and Verboven (2014)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Reynaert, Mathias, and Frank Verboven (2014). `Improving the performance of random coefficients demand models: The role of optimal instruments <https://ideas.repec.org/a/eee/econom/v179y2014i1p83-98.html>`_. *Journal of Econometrics, 179* (1), 83-98.


Reynaerts, Varadhan, and Nash (2012)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Reynaerts, Jo, Ravi Varadhan, and John C. Nash (2012). `Enhancing the convergence properties of the BLP (1995) contraction mapping <https://ideas.repec.org/p/ete/vivwps/35.html>`_. VIVES discussion paper 35.


Skrainka (2012)
~~~~~~~~~~~~~~~

Skrainka, Benjamin S. (2012). `A large scale study of the small sample performance of random coefficient models of demand <https://papers.ssrn.com/sol3/papers.cfm?abstract_id=1942627>`_.


Varadhan and Roland (2008)
~~~~~~~~~~~~~~~~~~~~~~~~~~

Varadhan, Ravi, and Christophe Roland (2008). `Simple and globally convergent methods for accelerating the convergence of any EM algorithm <https://ideas.repec.org/a/bla/scjsta/v35y2008i2p335-353.html>`_. *Scandinavian Journal of Statistics, 35* (2), 335-353.
